|Build badge|

.. |Build badge| image:: https://gitlab.com/sdurobotics/ur_rtde/badges/master/pipeline.svg
   :target: https://gitlab.com/sdurobotics/ur_rtde/commits/master

----------

Universal Robots RTDE C++ Interface
===================================
A C++ interface for controlling and receiving data from an UR robot using the `Real-Time Data Exchange (RTDE)
<https://www.universal-robots.com/how-tos-and-faqs/how-to/ur-how-tos/real-time-data-exchange-rtde-guide-22229/>`_.
The interface can also by used with python, through the provided python bindings.

.. toctree::
   :maxdepth: 3
   :caption: Table of Contents
   :glob:

   introduction/introduction
   faq/faq
   guides/guides
   installation/installation
   examples/examples
   api/api


